@@ -55,9 +55,6 @@ class AutoInt(TfBase, metaclass=ModelMeta):
         hidden_units="128,64,32",
         multi_sparse_combiner="sqrtn",
         seed=42,
-        k=10,
-        eval_batch_size=8192,
-        eval_user_num=None,
         lower_upper_bound=None,
         tf_sess_config=None,
         with_training=True,
@@ -100,9 +97,6 @@ class AutoInt(TfBase, metaclass=ModelMeta):
                 epsilon,
                 batch_size,
                 num_neg,
-                k,
-                eval_batch_size,
-                eval_user_num,
             )
 
     def _build_model(self):
