@@ -1,6 +1,7 @@
 """
 
-Reference: Heng-Tze Cheng et al. "Wide & Deep Learning for Recommender Systems"  (https://arxiv.org/pdf/1606.07792.pdf)
+Reference: Heng-Tze Cheng et al. "Wide & Deep Learning for Recommender Systems"
+           (https://arxiv.org/pdf/1606.07792.pdf)
 
 author: massquantity
 
