@@ -1,11 +1,10 @@
 import functools
 import time
 from contextlib import contextmanager
-from itertools import chain
+
 import numpy as np
-import tensorflow as tf2
-tf = tf2.compat.v1
-tf.disable_v2_behavior()
+
+from ..tfops import tf
 
 
 def shuffle_data(length, *args):
@@ -15,20 +14,17 @@ def shuffle_data(length, *args):
 
 def count_params():
     total_params = np.sum(
-        [
-            np.prod(v.get_shape().as_list())
-            for v in tf.trainable_variables()
-        ]
+        [np.prod(v.get_shape().as_list()) for v in tf.trainable_variables()]
     )
     embedding_params = np.sum(
         [
             np.prod(v.get_shape().as_list())
             for v in tf.trainable_variables()
             if (
-                'feat' in v.name
-                or 'weight' in v.name
-                or 'bias' in v.name
-                or 'embed' in v.name
+                "feat" in v.name
+                or "weight" in v.name
+                or "bias" in v.name
+                or "embed" in v.name
             )
         ]
     )
@@ -36,29 +32,17 @@ def count_params():
     total_params = f"{total_params:,}"
     embedding_params = f"{embedding_params:,}"
     network_params = f"{network_params:,}"
-    print_params = ("total params: "
-                    f"{colorize(total_params, 'yellow')} | "
-                    "embedding params: "
-                    f"{colorize(embedding_params, 'yellow')} | "
-                    "network params: "
-                    f"{colorize(network_params, 'yellow')}")
+    print_params = (
+        "total params: "
+        f"{colorize(total_params, 'yellow')} | "
+        "embedding params: "
+        f"{colorize(embedding_params, 'yellow')} | "
+        "network params: "
+        f"{colorize(network_params, 'yellow')}"
+    )
     print(print_params)
 
 
-def assign_oov_vector(model, add=True):
-    for v_name in chain.from_iterable(
-            [model.user_variables_np, model.item_variables_np]
-    ):
-        if v_name not in model.__dict__:
-            raise KeyError(f"{v_name} is not an attribute of the model.")
-        var = model.__dict__[v_name]
-        if var.ndim == 1:
-            var = np.append(var, np.mean(var))
-        else:
-            var = np.vstack([var, np.mean(var, axis=0)])
-        setattr(model, v_name, var)
-
-
 def time_func(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
@@ -67,6 +51,7 @@ def time_func(func):
         end = time.perf_counter()
         print(f"{func.__name__} elapsed: {(end - start):3.3f}s")
         return result
+
     return wrapper
 
 
@@ -104,9 +89,9 @@ def colorize(string, color, bold=False, highlight=False):
         num += 10
     attr.append(str(num))
     if bold:
-        attr.append('1')
-    attrs = ';'.join(attr)
-    return '\x1b[%sm%s\x1b[0m' % (attrs, string)
+        attr.append("1")
+    attrs = ";".join(attr)
+    return "\x1b[%sm%s\x1b[0m" % (attrs, string)
 
 
 color2num = dict(
@@ -118,5 +103,5 @@ color2num = dict(
     magenta=35,
     cyan=36,
     white=37,
-    crimson=38
+    crimson=38,
 )
